import argparse
import pkgutil
from secrets import randbelow
from typing import Dict, List


def get_list() -> Dict[str, str]:
    wordlist = pkgutil.get_data(__name__, 'eff_large_wordlist.txt').decode('utf-8')
    return {
        number: phrase
        for [number, phrase] in [line.strip().split('\t') for line in wordlist.strip().split('\n')]
    }


def get_phrase(diceware_list: Dict[str, str]) -> str:
    key = ''
    for i in range(5):
        key = key + str(randbelow(6) + 1)
    return diceware_list[key]


def generate_password(length: int) -> str:
    if length < 1:
        raise ValueError('Password must be at least one phrase')
    diceware_list = get_list()
    return ' '.join([get_phrase(diceware_list) for i in range(length)])


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument(
        'length',
        nargs='?',
        default=6,
        type=int,
        help='Number of words in the passphrase (defaults to 6)',
    )
    parsed = parser.parse_args()
    print(generate_password(parsed.length))


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['simple_diceware']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['diceware = simple_diceware.simple_diceware:main']}

setup_kwargs = {
    'name': 'simple-diceware',
    'version': '0.4.1',
    'description': 'Create diceware passwords from the command line',
    'long_description': '# Simple Diceware\n\nCreate diceware-style passwords from the command line. \n\nWordlist copied from https://www.eff.org/files/2016/07/18/eff_large_wordlist.txt\n\n### Install\n\n`pip install --user simple-diceware`\n\n### Use\n\n`diceware 6` to generate six-word passphrase\n',
    'author': 'Ben Chopson',
    'author_email': 'bchopson@users.noreply.github.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/bchopson/simple-diceware',
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
